/*Include: Board configuration*/
#include "IoTEVB.h"

/*Include: MCU peripheral Library*/
#include "stm32f10x_rcc.h"
#include "stm32f10x.h"

/*Include: W5500 iolibrary*/
#include "w5500.h"
#include "wizchip_conf.h"

/*Include: MCU Specific W5500 driver*/
#include "W5500HardwareDriver.h"

/*Include: Standard IO Library*/
#include <stdio.h>

/*Socket number defines*/
#define TCP_SOCKET	0
#define UDP_SOCKET	1

/*Port number defines*/
#define TCP_PORT 	60000
#define UDP_PORT 	60001

/*Receive Buffer Size define*/
#define BUFFER_SIZE	2048

/*Global variables*/
unsigned char testIP[4] = {0,0,0,0};

wiz_NetInfo gWIZNETINFO = { .mac = {0x00, 0x08, 0xdc, 0xab, 0xcd, 0xef},
							.ip = {192, 168, 11, 194},
							.sn = {255, 255, 255, 0},
							.gw = {192, 168, 11, 1},
							.dns = {8, 8, 8, 8},
							.dhcp = NETINFO_STATIC};

unsigned char tempBuffer[BUFFER_SIZE] = {};

/*Start of Main Functions*/
int main(void)
{
	led_ctrl led1,led2;
	/*Usart initialization for Debug.*/
	USART1Initialze();
		printf("USART initialized.\n\r");

	/*LED initialization.*/
	led_initialize();
	led1 = led2 = ON;

	led2Ctrl(led2);
	led1Ctrl(led1);

	/*W5500 initialization.*/
	W5500HardwareInitilize();
		printf("W5500 hardware interface initialized.\n\r");

	W5500Initialze();
		printf("W5500 IC initialized.\n\r");

	/*Set network informations*/
	wizchip_setnetinfo(&gWIZNETINFO);

	print_network_information();

	unsigned int recvsize;

	socket(TCP_SOCKET,Sn_MR_TCP,TCP_PORT,0);

	listen(TCP_SOCKET);

    while(1)
    {
    	if(getSn_SR(TCP_SOCKET) == SOCK_ESTABLISHED)
    	{
    		recvsize = recv(TCP_SOCKET,tempBuffer,BUFFER_SIZE);
    		if(recvsize)
    		{
    			if(strcmp(tempBuffer,"led on") == 0)
    			{
    				led1Ctrl(ON);
    				send(TCP_SOCKET,"led on",6);
    			}
    			else if(strcmp(tempBuffer,"led off") == 0)
    			{
    				led1Ctrl(OFF);
    				send(TCP_SOCKET,"led off",6);
    			}
    			memset(tempBuffer,0,BUFFER_SIZE);
    		}
    	}
    	else if(getSn_SR(TCP_SOCKET) == SOCK_CLOSE_WAIT)
    	{
    		disconnect(TCP_SOCKET);
    	}
    }
}
